==> haskell-persistent-mysql-2.13.0.1-179-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-mysql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-mysql
version:              2.13.0.1
visibility:           public
id:                   persistent-mysql-2.13.0.1-7TmZ2QgBUHhFgN2a5rsSHx
key:                  persistent-mysql-2.13.0.1-7TmZ2QgBUHhFgN2a5rsSHx
license:              MIT
maintainer:           Felipe Lessa <felipe.lessa@gmail.com>
author:               Felipe Lessa <felipe.lessa@gmail.com>, Michael Snoyman
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:
    Backend for the persistent library using MySQL database server.

description:
    This package contains a backend for persistent using the
    MySQL database server.  Internally it uses the @mysql-simple@
    and @mysql@ packages in order to access the database.

    This package supports only MySQL 5.1 and above.  However, it
    has been tested only on MySQL 5.5.
    Only the InnoDB storage engine is officially supported.

    Known problems:

    * This package does not support statements inside other
    statements.

category:             Database, Yesod
abi:                  17b64cb37dffc14fcd5a5e2217a09afd
exposed:              True
exposed-modules:      Database.Persist.MySQL
import-dirs:          /usr/lib/ghc-9.0.2/site-local/persistent-mysql-2.13.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/persistent-mysql-2.13.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-mysql
hs-libraries:         HSpersistent-mysql-2.13.0.1-7TmZ2QgBUHhFgN2a5rsSHx
depends:
    aeson-1.5.6.0-D6JFXMoVVY440Mpm8YlAiW base-4.15.1.0
    blaze-builder-0.4.2.2-2gLNFpRfQ1I6uT3J9lURjU bytestring-0.10.12.1
    conduit-1.3.4.2-9I6SWmQfQ5n2ocDACiIrO5 containers-0.6.4.1
    monad-logger-0.3.36-mmXF6ZrC1u54MrBmqCWhx
    mysql-0.2.1-7hGOqIYurZo96E4xjTe6Cv
    mysql-simple-0.4.7.2-4B3irokApaHJf9udRI0Hm2
    persistent-2.13.3.1-33Qeko4G5uSFHEw4jKsOAX
    resource-pool-0.2.3.2-FSx3X53T7YTBsbh6dyp0x
    resourcet-1.2.5-3RawzU30J2N1PmCdN1TN1S text-1.2.5.0
    transformers-0.5.6.2 unliftio-core-0.2.0.1-HjGpVpPktr5Bc3kYrL6LtS

haddock-interfaces:
    /usr/share/doc/haskell-persistent-mysql/html/persistent-mysql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-mysql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-mysql-2.13.0.1-180-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-mysql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-mysql
version:              2.13.0.1
visibility:           public
id:                   persistent-mysql-2.13.0.1-BA1q3Q5ZE2RHEdtqBaTl6S
key:                  persistent-mysql-2.13.0.1-BA1q3Q5ZE2RHEdtqBaTl6S
license:              MIT
maintainer:           Felipe Lessa <felipe.lessa@gmail.com>
author:               Felipe Lessa <felipe.lessa@gmail.com>, Michael Snoyman
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:
    Backend for the persistent library using MySQL database server.

description:
    This package contains a backend for persistent using the
    MySQL database server.  Internally it uses the @mysql-simple@
    and @mysql@ packages in order to access the database.

    This package supports only MySQL 5.1 and above.  However, it
    has been tested only on MySQL 5.5.
    Only the InnoDB storage engine is officially supported.

    Known problems:

    * This package does not support statements inside other
    statements.

category:             Database, Yesod
abi:                  75a6e7fd5f87ffe6f37a2292e17ff5b7
exposed:              True
exposed-modules:      Database.Persist.MySQL
import-dirs:          /usr/lib/ghc-9.0.2/site-local/persistent-mysql-2.13.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/persistent-mysql-2.13.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-mysql
hs-libraries:         HSpersistent-mysql-2.13.0.1-BA1q3Q5ZE2RHEdtqBaTl6S
depends:
    aeson-1.5.6.0-D6JFXMoVVY440Mpm8YlAiW base-4.15.1.0
    blaze-builder-0.4.2.2-2gLNFpRfQ1I6uT3J9lURjU bytestring-0.10.12.1
    conduit-1.3.4.2-9I6SWmQfQ5n2ocDACiIrO5 containers-0.6.4.1
    monad-logger-0.3.36-7BPfz4Ja4D56WwgaoNxH3v
    mysql-0.2.1-7hGOqIYurZo96E4xjTe6Cv
    mysql-simple-0.4.7.2-4B3irokApaHJf9udRI0Hm2
    persistent-2.13.3.1-I0pmrzL1H0N43R52GTOUsa
    resource-pool-0.2.3.2-FSx3X53T7YTBsbh6dyp0x
    resourcet-1.2.5-3RawzU30J2N1PmCdN1TN1S text-1.2.5.0
    transformers-0.5.6.2 unliftio-core-0.2.0.1-HjGpVpPktr5Bc3kYrL6LtS

haddock-interfaces:
    /usr/share/doc/haskell-persistent-mysql/html/persistent-mysql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-mysql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
